"""
Class object for CasaTunesZone
Documentation: https://github.com/jonkristian/pycasatunes

Generated by generator/generator.py - 2021-07-29 23:36:53.998174
"""
from typing import List
from .base import CasaBase, CasaBaseClient
from pycasatunes.objects.media import CasaTunesMedia


class Zonegroupinfo(CasaBase):
    @property
    def zoneId(self):
        return self.attributes.get("zoneId", None)

    @property
    def master(self):
        return self.attributes.get("master", False)

    @property
    def keypadLock(self):
        return self.attributes.get("keypadLock", False)

    @property
    def volumeAdjustment(self):
        return self.attributes.get("volumeAdjustment", None)

    @property
    def powerOnVolumeAdjustment(self):
        return self.attributes.get("powerOnVolumeAdjustment", None)


class CasaTunesZone(CasaBaseClient):
    @property
    def Balance(self):
        return self.attributes.get("Balance", None)

    @property
    def Bass(self):
        return self.attributes.get("Bass", None)

    @property
    def DND(self):
        return self.attributes.get("DND", False)

    @property
    def Shared(self):
        return self.attributes.get("Shared", False)

    @property
    def FixedVolume(self):
        return self.attributes.get("FixedVolume", None)

    @property
    def FixedVolumeEnabled(self):
        return self.attributes.get("FixedVolumeEnabled", False)

    @property
    def Hidden(self):
        return self.attributes.get("Hidden", False)

    @property
    def KeypadLock(self):
        return self.attributes.get("KeypadLock", False)

    @property
    def Loudness(self):
        return self.attributes.get("Loudness", False)

    @property
    def LowPassFilterEnabled(self):
        return self.attributes.get("LowPassFilterEnabled", False)

    @property
    def LowPassFilterSupported(self):
        return self.attributes.get("LowPassFilterSupported", False)

    @property
    def LowPassFilter(self):
        return self.attributes.get("LowPassFilter", None)

    @property
    def MasterMode(self):
        return self.attributes.get("MasterMode", False)

    @property
    def Mute(self):
        return self.attributes.get("Mute", False)

    @property
    def Name(self):
        return self.attributes.get("Name", "")

    @property
    def PartyMode(self):
        return self.attributes.get("PartyMode", False)

    @property
    def Power(self):
        return self.attributes.get("Power", True)

    @property
    def MaxVolume(self):
        return self.attributes.get("MaxVolume", None)

    @property
    def VolumeControlType(self):
        return self.attributes.get("VolumeControlType", None)

    @property
    def ZoneGroupInfo(self):
        return Zonegroupinfo(self.attributes.get("ZoneGroupInfo", {}))

    @property
    def SharedRoomID(self):
        return self.attributes.get("SharedRoomID", False)

    @property
    def GroupName(self):
        return self.attributes.get("GroupName", "")

    @property
    def SleepEnabled(self):
        return self.attributes.get("SleepEnabled", False)

    @property
    def SourceID(self):
        return self.attributes.get("SourceID", None)

    @property
    def Treble(self):
        return self.attributes.get("Treble", None)

    @property
    def Volume(self):
        return self.attributes.get("Volume", None)

    @property
    def WakeupEventSchedule(self):
        return self.attributes.get("WakeupEventSchedule", False)

    @property
    def WakeupScheduled(self):
        return self.attributes.get("WakeupScheduled", False)

    @property
    def ZoneID(self):
        return self.attributes.get("ZoneID", None)

    @property
    def EnabledSources(self):
        return self.attributes.get("EnabledSources", None)

    @property
    def EnableMuteOrPage(self):
        return self.attributes.get("EnableMuteOrPage", None)

    @property
    def PageVolume(self):
        return self.attributes.get("PageVolume", None)

    @property
    def PowerOnVolume(self):
        return self.attributes.get("PowerOnVolume", None)

    @property
    def ResetPowerOnVolume(self):
        return self.attributes.get("ResetPowerOnVolume", False)

    @property
    def PersistentZoneID(self):
        return self.attributes.get("PersistentZoneID", "")

    @property
    def ZoneImageID(self):
        return self.attributes.get("ZoneImageID", "")

    @property
    def EqType(self):
        return self.attributes.get("EqType", None)

    @property
    def HidePowerControl(self):
        return self.attributes.get("HidePowerControl", False)

    @property
    def HideSourceControl(self):
        return self.attributes.get("HideSourceControl", False)

    @property
    def HideDNDControl(self):
        return self.attributes.get("HideDNDControl", False)

    @property
    def ZoneNameReadOnly(self):
        return self.attributes.get("ZoneNameReadOnly", False)


"""
Class object for CasaTunesSource
Documentation: https://github.com/jonkristian/pycasatunes

Generated by generator/generator.py - 2021-08-03 20:35:05.287334
"""
from .base import CasaBaseClient


class CasaTunesSource(CasaBaseClient):
    @property
    def Hidden(self):
        return self.attributes.get("Hidden", False)

    @property
    def IsShared(self):
        return self.attributes.get("IsShared", False)

    @property
    def Name(self):
        return self.attributes.get("Name", "")

    @property
    def MediaTypesSupported(self):
        return self.attributes.get("MediaTypesSupported", None)

    @property
    def Type(self):
        return self.attributes.get("Type", None)

    @property
    def SourceType(self):
        return self.attributes.get("SourceType", None)

    @property
    def SourceID(self):
        return self.attributes.get("SourceID", None)

    @property
    def ExternalDeviceType(self):
        return self.attributes.get("ExternalDeviceType", None)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pycasatunes', 'pycasatunes.objects']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=3.7.4,<4.0.0']

setup_kwargs = {
    'name': 'pycasatunes',
    'version': '0.1.2',
    'description': 'Asynchronous python client for CasaTunes.',
    'long_description': '# PyCasaTunes\n\nAsynchronous python client for CasaTunes.\nThis package allows you to interact with CasaTunes API to control your home audio.\n\n## Installation\n\n```bash\npip install pycasatunes\n```\n\n## Attributions\n- [@timmo001](https://github.com/timmo001) for source of inspiration with his [aiolyric package](https://github.com/timmo001/aiolyric).\n- [@ludeeus](https://github.com/ludeeus) for his generator class.\n\n#\n\n⭐️ this repository if you found it useful ❤️\n\n<a href="https://www.buymeacoffee.com/jonkristian" target="_blank"><img src="https://bmc-cdn.nyc3.digitaloceanspaces.com/BMC-button-images/custom_images/white_img.png" alt="Buy Me A Coffee" style="height: auto !important;width: auto !important;" ></a>',
    'author': 'Jon Kristian Nilsen',
    'author_email': 'hello@jonkristian.no',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/jonkristian/pycasatunes',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



"""
Class object for CasaTunesNowPlaying
Documentation: https://github.com/jonkristian/pycasatunes

Generated by generator/generator.py - 2021-08-03 20:16:46.206915
"""
from .base import CasaBase, CasaBaseClient


class Bookmarkscope(CasaBase):
    @property
    def ID(self):
        return self.attributes.get("ID", "")

    @property
    def PersistentID(self):
        return self.attributes.get("PersistentID", "")

    @property
    def Title(self):
        return self.attributes.get("Title", "")

    @property
    def Flags(self):
        return self.attributes.get("Flags", None)


class Deeplinks(CasaBase):
    @property
    def Kind(self):
        return self.attributes.get("Kind", "")

    @property
    def Title(self):
        return self.attributes.get("Title", "")

    @property
    def Uri(self):
        return self.attributes.get("Uri", "")

    @property
    def MediaId(self):
        return self.attributes.get("MediaId", "")


class Contextmenuitems(CasaBase):
    @property
    def Type(self):
        return self.attributes.get("Type", None)

    @property
    def Key(self):
        return self.attributes.get("Key", "")

    @property
    def Title(self):
        return self.attributes.get("Title", "")

    @property
    def Value(self):
        return self.attributes.get("Value", "")


class Currsong(CasaBase):
    @property
    def Flags(self):
        return self.attributes.get("Flags", None)

    @property
    def QueueType(self):
        return self.attributes.get("QueueType", "")

    @property
    def ID(self):
        return self.attributes.get("ID", "")

    @property
    def PersistentID(self):
        return self.attributes.get("PersistentID", "")

    @property
    def Title(self):
        return self.attributes.get("Title", "")

    @property
    def Type(self):
        return self.attributes.get("Type", None)

    @property
    def ArtworkURI(self):
        return self.attributes.get("ArtworkURI", "")

    @property
    def ArtworkRatio(self):
        return self.attributes.get("ArtworkRatio", None)

    @property
    def Album(self):
        return self.attributes.get("Album", "")

    @property
    def Artists(self):
        return self.attributes.get("Artists", "")

    @property
    def Duration(self):
        return self.attributes.get("Duration", None)

    @property
    def DeepLinks(self):
        return [Deeplinks(x) for x in self.attributes.get("DeepLinks", [])]

    @property
    def BitRate(self):
        return self.attributes.get("BitRate", None)

    @property
    def ListenerCount(self):
        return self.attributes.get("ListenerCount", None)

    @property
    def Rating(self):
        return self.attributes.get("Rating", None)

    @property
    def TotalItems(self):
        return self.attributes.get("TotalItems", None)

    @property
    def DisplayInfo(self):
        return self.attributes.get("DisplayInfo", [])

    @property
    def ContextMenuItems(self):
        return [
            Contextmenuitems(x) for x in self.attributes.get("ContextMenuItems", [])
        ]

    @property
    def AccountName(self):
        return self.attributes.get("AccountName", "")


class Deeplinks(CasaBase):
    @property
    def Kind(self):
        return self.attributes.get("Kind", "")

    @property
    def Title(self):
        return self.attributes.get("Title", "")

    @property
    def Uri(self):
        return self.attributes.get("Uri", "")

    @property
    def MediaId(self):
        return self.attributes.get("MediaId", "")


class Contextmenuitems(CasaBase):
    @property
    def Type(self):
        return self.attributes.get("Type", None)

    @property
    def Key(self):
        return self.attributes.get("Key", "")

    @property
    def Title(self):
        return self.attributes.get("Title", "")

    @property
    def Value(self):
        return self.attributes.get("Value", "")


class Nextsong(CasaBase):
    @property
    def Flags(self):
        return self.attributes.get("Flags", None)

    @property
    def QueueType(self):
        return self.attributes.get("QueueType", "")

    @property
    def ID(self):
        return self.attributes.get("ID", "")

    @property
    def PersistentID(self):
        return self.attributes.get("PersistentID", "")

    @property
    def Title(self):
        return self.attributes.get("Title", "")

    @property
    def Type(self):
        return self.attributes.get("Type", None)

    @property
    def ArtworkURI(self):
        return self.attributes.get("ArtworkURI", "")

    @property
    def ArtworkRatio(self):
        return self.attributes.get("ArtworkRatio", None)

    @property
    def Album(self):
        return self.attributes.get("Album", "")

    @property
    def Artists(self):
        return self.attributes.get("Artists", "")

    @property
    def Duration(self):
        return self.attributes.get("Duration", None)

    @property
    def DeepLinks(self):
        return [Deeplinks(x) for x in self.attributes.get("DeepLinks", [])]

    @property
    def BitRate(self):
        return self.attributes.get("BitRate", None)

    @property
    def ListenerCount(self):
        return self.attributes.get("ListenerCount", None)

    @property
    def Rating(self):
        return self.attributes.get("Rating", None)

    @property
    def TotalItems(self):
        return self.attributes.get("TotalItems", None)

    @property
    def DisplayInfo(self):
        return self.attributes.get("DisplayInfo", [])

    @property
    def ContextMenuItems(self):
        return [
            Contextmenuitems(x) for x in self.attributes.get("ContextMenuItems", [])
        ]


class CasaTunesNowPlaying(CasaBaseClient):
    @property
    def SourceID(self):
        return self.attributes.get("SourceID", None)

    @property
    def QueueCount(self):
        return self.attributes.get("QueueCount", None)

    @property
    def QueueSongIndex(self):
        return self.attributes.get("QueueSongIndex", None)

    @property
    def ChangeQueueID(self):
        return self.attributes.get("ChangeQueueID", None)

    @property
    def ChangeMetaDataID(self):
        return self.attributes.get("ChangeMetaDataID", None)

    @property
    def ChangeBookmarkID(self):
        return self.attributes.get("ChangeBookmarkID", None)

    @property
    def BookmarkScope(self):
        return Bookmarkscope(self.attributes.get("BookmarkScope", {}))

    @property
    def Status(self):
        return self.attributes.get("Status", None)

    @property
    def Controls(self):
        return self.attributes.get("Controls", None)

    @property
    def RepeatMode(self):
        return self.attributes.get("RepeatMode", None)

    @property
    def ShuffleMode(self):
        return self.attributes.get("ShuffleMode", False)

    @property
    def CurrSong(self):
        return Currsong(self.attributes.get("CurrSong", {}))

    @property
    def NextSong(self):
        return Nextsong(self.attributes.get("NextSong", {}))

    @property
    def CurrProgress(self):
        return self.attributes.get("CurrProgress", None)

    @property
    def SearchPromptText(self):
        return self.attributes.get("SearchPromptText", "")

    @property
    def SourceLockedByZoneID(self):
        return self.attributes.get("SourceLockedByZoneID", None)

    @property
    def ServiceName(self):
        return self.attributes.get("ServiceName", "")

    @property
    def ServiceID(self):
        return self.attributes.get("ServiceID", "")

    @property
    def ServiceLogoURI(self):
        return self.attributes.get("ServiceLogoURI", "")



"""
Class object for CasaTunesSystem
Documentation: https://github.com/jonkristian/pycasatunes

Generated by generator/generator.py - 2021-07-31 12:29:43.406741
"""
from .base import CasaBase, CasaBaseClient


class Eqsettings(CasaBase):
    @property
    def Minimum(self):
        return self.attributes.get("Minimum", None)

    @property
    def Maximum(self):
        return self.attributes.get("Maximum", None)

    @property
    def Increment(self):
        return self.attributes.get("Increment", None)


class Volumesettings(CasaBase):
    @property
    def Minimum(self):
        return self.attributes.get("Minimum", None)

    @property
    def Maximum(self):
        return self.attributes.get("Maximum", None)

    @property
    def Increment(self):
        return self.attributes.get("Increment", None)


class Values(CasaBase):
    @property
    def Name(self):
        return self.attributes.get("Name", "")

    @property
    def Value(self):
        return self.attributes.get("Value", "")

    @property
    def IsError(self):
        return self.attributes.get("IsError", False)


class Matrixinfo(CasaBase):
    @property
    def Title(self):
        return self.attributes.get("Title", "")

    @property
    def Values(self):
        return [Values(x) for x in self.attributes.get("Values", [])]


class CasaTunesSystem(CasaBaseClient):
    @property
    def AppName(self):
        return self.attributes.get("AppName", "")

    @property
    def ControllerFeatures(self):
        return self.attributes.get("ControllerFeatures", None)

    @property
    def EQSettings(self):
        return Eqsettings(self.attributes.get("EQSettings", {}))

    @property
    def VolumeSettings(self):
        return Volumesettings(self.attributes.get("VolumeSettings", {}))

    @property
    def MACAddress(self):
        return self.attributes.get("MACAddress", "")

    @property
    def TeamViewerMACAddress(self):
        return self.attributes.get("TeamViewerMACAddress", "")

    @property
    def IPAddress(self):
        return self.attributes.get("IPAddress", "")

    @property
    def CasaTunesVersion(self):
        return self.attributes.get("CasaTunesVersion", "")

    @property
    def WebServicesVersion(self):
        return self.attributes.get("WebServicesVersion", "")

    @property
    def RESTServicesVersion(self):
        return self.attributes.get("RESTServicesVersion", "")

    @property
    def IsLicenseValid(self):
        return self.attributes.get("IsLicenseValid", True)

    @property
    def IsCAMSupported(self):
        return self.attributes.get("IsCAMSupported", None)

    @property
    def IsAirableLicensed(self):
        return self.attributes.get("IsAirableLicensed", False)

    @property
    def IsSystemSleepEnabled(self):
        return self.attributes.get("IsSystemSleepEnabled", False)

    @property
    def IsPasswordRequired(self):
        return self.attributes.get("IsPasswordRequired", False)

    @property
    def StreamerModeEnabled(self):
        return self.attributes.get("StreamerModeEnabled", False)

    @property
    def IsSettingsPasswordRequired(self):
        return self.attributes.get("IsSettingsPasswordRequired", False)

    @property
    def IsPrayersEnabled(self):
        return self.attributes.get("IsPrayersEnabled", True)

    @property
    def IndexerPort(self):
        return self.attributes.get("IndexerPort", None)

    @property
    def MatrixInfo(self):
        return [Matrixinfo(x) for x in self.attributes.get("MatrixInfo", [])]



"""CasaTunes: Init"""
import logging

from aiohttp import ClientResponse
from typing import List

from .const import API_PORT
from .objects.base import CasaBase
from .objects.system import CasaTunesSystem
from .objects.zone import CasaTunesZone
from .objects.media import CasaTunesMedia
from .objects.source import CasaTunesSource
from .objects.nowplaying import CasaTunesNowPlaying
from .client import CasaClient


class CasaTunes(CasaBase):
    """Interacting with CasaTunes API."""

    logger = logging.getLogger(__name__)

    def __init__(self, client: "CasaClient", host: str) -> None:
        """Initialize the appliance."""
        self._client = client
        self._host = host
        self._system: CasaTunesSystem

        self._zones: List[CasaTunesZone] = []
        self._zones_dict: dict = {}

        self._sources: List[CasaTunesSource] = []
        self._sources_dict: dict = {}

        self._nowplaying: List[CasaTunesNowPlaying] = []
        self._nowplaying_dict: dict = {}

    @property
    def host(self) -> str:
        return self._host

    @property
    def system(self) -> dict:
        return self._system

    @property
    def zones(self) -> dict:
        return self._zones

    @property
    def zones_dict(self) -> dict:
        return self._zones_dict

    @property
    def sources(self) -> dict:
        return self._sources

    @property
    def sources_dict(self) -> dict:
        return self._sources_dict

    @property
    def nowplaying(self) -> dict:
        return self._nowplaying

    @property
    def nowplaying_dict(self) -> dict:
        return self._nowplaying_dict

    async def fetch(self) -> None:
        """Fetch data from CasaTunes zone."""
        data: dict = {}
        data["system"] = await self.get_system()
        data["zones"] = await self.get_zones()
        data["sources"] = await self.get_sources()
        data["nowplaying"] = await self.get_nowplaying()

        return data

    async def get_system(self) -> None:
        """Get System."""
        response: ClientResponse = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/system/info"
        )
        json = await response.json()
        self.logger.debug(json)
        system = [CasaTunesSystem(self._client, json)]
        self._system = system[0]

        return self._system

    async def get_zones(self) -> None:
        """Get Zones."""
        response: ClientResponse = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/zones"
        )
        json = await response.json()
        self.logger.debug(json)
        self._zones = [CasaTunesZone(self._client, ZoneID) for ZoneID in json or []]

        self._zones_dict: dict = {}
        for zone in self._zones:
            self._zones_dict[zone.ZoneID] = zone

    async def get_sources(self) -> CasaTunesSource:
        """Get Sources."""
        response = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/sources"
        )
        json = await response.json()
        self.logger.debug(json)

        self._sources = [
            CasaTunesSource(self._client, SourceID) for SourceID in json or []
        ]

        self._sources_dict: dict = {}
        for source in self._sources:
            self._sources_dict[source.SourceID] = source

    async def get_nowplaying(self) -> CasaTunesNowPlaying:
        response = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/sources/nowplaying"
        )
        json = await response.json()
        self.logger.debug(json)
        self._nowplaying = [
            CasaTunesNowPlaying(self._client, SourceID) for SourceID in json or []
        ]

        self._nowplaying_dict: dict = {}
        for item in self._nowplaying:
            self._nowplaying_dict[item.SourceID] = item

    async def get_media(self, opts = {}) -> CasaTunesMedia:
        """Get Zone Media."""
        if 'zone_id' in opts:
            if 'item_id' in opts:
                response = await self._client.get(
                    f"http://{self._host}:{API_PORT}/api/v1/media/{opts['item_id']}?limit={opts['limit']}"
                )
            else:
                response = await self._client.get(
                    f"http://{self._host}:{API_PORT}/api/v1/media/zones/{opts['zone_id']}?limit={opts['limit']}"
                )

        json = await response.json()
        self.logger.debug(json)

        return json

    async def search_media(self, zone_id, keyword) -> CasaTunesMedia:
        """Get Zone Media."""
        response = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/media/zones/{zone_id}/search/{keyword}"
        )

        json = await response.json()
        self.logger.debug(json)

        return json

    async def play_media(self, zone_id, media_id):
        """Send player action and option."""
        response = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/media/zones/{zone_id}/play/{media_id}"
        )
        json = await response.json()
        self.logger.debug(json)

    async def get_image(self, image_id) -> CasaTunesMedia:
        """Get Image."""
        return f"http://{self._host}:{API_PORT}/api/v1/images/{image_id}"

    async def turn_on(self, zone_id):
        response = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/zones/{zone_id}?Power=on"
        )
        json = await response.json()
        self.logger.debug(json)

    async def turn_off(self, zone_id):
        response = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/zones/{zone_id}?Power=off"
        )
        json = await response.json()
        self.logger.debug(json)

    async def mute_volume(self, zone_id, mute):
        response = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/zones/{zone_id}?Mute={mute}"
        )
        json = await response.json()
        self.logger.debug(json)

    async def set_volume_level(self, zone_id, volume):
        response = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/zones/{zone_id}?Volume={volume}"
        )
        json = await response.json()
        self.logger.debug(json)

    async def change_source(self, zone_id, source):
        """Send player action and option."""
        response = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/zones/{zone_id}?SourceID={source}"
        )
        json = await response.json()
        self.logger.debug(json)

    async def player_action(self, zone_id, action, option=""):
        """Send player action and option."""
        response = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/zones/{zone_id}/player/{action}/{option}"
        )
        json = await response.json()
        self.logger.debug(json)

    async def zone_master(self, zone_id, mode):
        """Set Zone master flag."""
        response = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/zones/{zone_id}/?MasterMode={mode}"
        )
        json = await response.json()
        self.logger.debug(json)

    async def zone_join(self, zone_id, client_zone_id):
        """Join a CasaTunes zone with a zone."""
        response = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/zones/{zone_id}/group/{client_zone_id}"
        )
        json = await response.json()
        self.logger.debug(json)

    async def zone_unjoin(self, zone_id, client_zone_id):
        """Unjoin a CasaTunes zone with a zone."""
        response = await self._client.get(
            f"http://{self._host}:{API_PORT}/api/v1/zones/{zone_id}/ungroup/{client_zone_id}"
        )
        json = await response.json()
        self.logger.debug(json)



"""
Class object for CasaTunesMedia
Documentation: https://github.com/jonkristian/pycasatunes

Generated by generator/generator.py - 2021-08-09 10:27:19.167654
"""
from .base import CasaBase, CasaBaseClient


class Contextmenuitems(CasaBase):
    @property
    def Type(self):
        return self.attributes.get("Type", None)

    @property
    def Key(self):
        return self.attributes.get("Key", "")

    @property
    def Title(self):
        return self.attributes.get("Title", "")

    @property
    def Value(self):
        return self.attributes.get("Value", "")


class Mediaitems(CasaBase):
    @property
    def Flags(self):
        return self.attributes.get("Flags", None)

    @property
    def QueueType(self):
        return self.attributes.get("QueueType", "")

    @property
    def ID(self):
        return self.attributes.get("ID", "")

    @property
    def PersistentID(self):
        return self.attributes.get("PersistentID", "")

    @property
    def GroupName(self):
        return self.attributes.get("GroupName", "")

    @property
    def Title(self):
        return self.attributes.get("Title", "")

    @property
    def Type(self):
        return self.attributes.get("Type", None)

    @property
    def ArtworkURI(self):
        return self.attributes.get("ArtworkURI", "")

    @property
    def ArtworkRatio(self):
        return self.attributes.get("ArtworkRatio", None)

    @property
    def Duration(self):
        return self.attributes.get("Duration", None)

    @property
    def BitRate(self):
        return self.attributes.get("BitRate", None)

    @property
    def ListenerCount(self):
        return self.attributes.get("ListenerCount", None)

    @property
    def Rating(self):
        return self.attributes.get("Rating", None)

    @property
    def TotalItems(self):
        return self.attributes.get("TotalItems", None)

    @property
    def DisplayInfo(self):
        return self.attributes.get("DisplayInfo", [])

    @property
    def ContextMenuItems(self):
        return [
            Contextmenuitems(x) for x in self.attributes.get("ContextMenuItems", [])
        ]


class CasaTunesMedia(CasaBaseClient):
    @property
    def Flags(self):
        return self.attributes.get("Flags", None)

    @property
    def QueueType(self):
        return self.attributes.get("QueueType", "")

    @property
    def ID(self):
        return self.attributes.get("ID", "")

    @property
    def PersistentID(self):
        return self.attributes.get("PersistentID", "")

    @property
    def Title(self):
        return self.attributes.get("Title", "")

    @property
    def DisplayInfo(self):
        return self.attributes.get("DisplayInfo", [])

    @property
    def ArtworkRatio(self):
        return self.attributes.get("ArtworkRatio", None)

    @property
    def SearchPlaceholderText(self):
        return self.attributes.get("SearchPlaceholderText", "")

    @property
    def StartIndex(self):
        return self.attributes.get("StartIndex", None)

    @property
    def TotalAvailable(self):
        return self.attributes.get("TotalAvailable", None)

    @property
    def MediaItems(self):
        return [Mediaitems(x) for x in self.attributes.get("MediaItems", [])]
